==> wmconfig-1.2.5.tar.bz2: wmconfig-1.2.5/pwm.c <==
/*
 * Copyright (C) 2003
 *	Tommy Scheunemann <net@arrishq.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"
#include <stdio.h>
extern unsigned int flags;

/*
 Pwm requires submenus defined before they are
 used - Wmconfig uses a "reverse" output
*/

void output_pwm(struct group *root, char *use_term)
{
 struct item *item;
 if (root == (struct group *)NULL)
  return;
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_MENU)
   output_pwm(item->data, use_term);
  item++;
 }
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;
  }
  item++;
 }
 item = root->items;
 printf("menu \"%s\", \"%s\" {\n", root->name, root->name);    
 while (item->type != 0) {
  if (item->type == ITEM_MENU) {
   struct group *tmp;
   tmp = (struct group *)item->data;
   printf(" submenu \"%s\"\n", tmp->name);
  } else if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;
   if (app->restart) {
    if (strncasecmp(app->restart, "restart", 7) == 0)
     printf(" entry \"%s\", \"restart\"\n", app->name);
    else if (strncasecmp(app->restart, "quit", 4) == 0)
     printf(" entry \"%s\", \"exit\"\n", app->name);
    else
     printf(" entry \"%s\", \"restart_other\", \"%s\"\n", app->name, app->exec);
   } else {
    if (app->name && app->exec && app->terminal) {
     printf(" entry \"%s\", \"exec\", \"%s -e %s\"\n", app->name, use_term, app->exec);
    } else if (app->name && app->exec) {
     printf(" entry \"%s\", \"exec\", \"%s\"\n", app->name, app->exec);
    }
   }
  }
  item++;
 }
 printf("}\n\n");
 return;
}

==> wmconfig-1.3.3.tar.bz2: wmconfig-1.3.3/pwm.c <==
/*
 * Copyright (C) 2003
 *	Tommy Scheunemann <net@arrishq.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"

#include <stdio.h>
#include <strings.h>

extern unsigned int flags;

/*
 Pwm requires submenus defined before they are
 used - Wmconfig uses a "reverse" output
*/

void output_pwm(struct group *root,const char *use_term)
{
 struct item *item;
 if (root == (struct group *)NULL)
  return;
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_MENU)
   output_pwm(item->data, use_term);
  item++;
 }
 item = root->items;
 while (item->type != 0) {
  if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;
  }
  item++;
 }
 item = root->items;
 printf("menu \"%s\", \"%s\" {\n", root->name, root->name);    
 while (item->type != 0) {
  if (item->type == ITEM_MENU) {
   struct group *tmp;
   tmp = (struct group *)item->data;
   printf(" submenu \"%s\"\n", tmp->name);
  } else if (item->type == ITEM_APP) {
   struct package *app;
   app = (struct package *)item->data;
   if (app->restart) {
    if (strncasecmp(app->restart, "restart", 7) == 0)
     printf(" entry \"%s\", \"restart\"\n", app->name);
    else if (strncasecmp(app->restart, "quit", 4) == 0)
     printf(" entry \"%s\", \"exit\"\n", app->name);
    else
     printf(" entry \"%s\", \"restart_other\", \"%s\"\n", app->name, app->exec);
   } else {
    if (app->name && app->exec && app->terminal) {
     printf(" entry \"%s\", \"exec\", \"%s -e %s\"\n", app->name, use_term, app->exec);
    } else if (app->name && app->exec) {
     printf(" entry \"%s\", \"exec\", \"%s\"\n", app->name, app->exec);
    }
   }
  }
  item++;
 }
 printf("}\n\n");
 return;
}
